@@ -1,5 +1,6 @@
 from typing import Generator, List, TYPE_CHECKING
 
+from anypoint.models.api import Asset
 from anypoint.models.application import Application
 
 if TYPE_CHECKING:
@@ -24,3 +25,6 @@ class Environment:
 
     def get_applications(self) -> Generator[Application, None, None]:
         return self._client.applications.get_applications(self.id)
+
+    def get_apis(self) -> List[Asset]:
+        return self._client.api_manager.get_apis(self.organization_id, self.id)
